﻿using System;
using zipkin4net;
using zipkin4net.Tracers.Zipkin;
using zipkin4net.Transport.Http;

namespace zipkinDotnetManual
{
    class Program
    {
        public static void InitTracer()
        {
            TraceManager.SamplingRate = 1.0f;
            var logger = new ConsoleLogger();
            //(访问https://tracing-analysis.console.aliyun.com 获取zipkin endpoint, 注意endpoint中不包含“/api/v2/spans");
            var httpSender = new HttpZipkinSender("http://tracing-analysis-dc-hz.aliyuncs.com/adapt_adapt_your_token", "application/json");

            var tracer = new ZipkinTracer(httpSender, new JSONSpanSerializer());
            TraceManager.RegisterTracer(tracer);
            
            TraceManager.Start(logger);
        }
        static void Main(string[] args)
        {
            InitTracer();
            Console.WriteLine("start tracing...");
            testTracing();
            Console.WriteLine("end tracing...");
            Console.WriteLine("Press any key to exit...");
            Console.ReadKey();
            TraceManager.Stop();
        }

        private static void testTracing()
        {
            var trace = Trace.Create();
           
            Trace.Current = trace;
            trace.Record(Annotations.ClientSend());
           
            trace.Record(Annotations.Rpc("client"));
            trace.Record(Annotations.Tag("mytag", "spanFrist"));
            trace.Record(Annotations.ServiceName("dotnetManual"));
            // ...do business
            testCall();

            trace.Record(Annotations.ClientRecv());

        }

        private static void testCall()
        {
            var trace = Trace.Current.Child();
            Trace.Current = trace;
            trace.Record(Annotations.ServerRecv());
            trace.Record(Annotations.Rpc("server"));
            trace.Record(Annotations.Tag("mytag", "spanSecond"));
            trace.Record(Annotations.ServiceName("dotnetManual"));

            // ...do business
            trace.Record(Annotations.ServerSend());
        }
    
}
}
